添加一个tool。作用是获取账号下全部的已经上传的病人影像序列信息

接口是 baseurl + /api/v3/getStudies，请求类型POST，入参如下：

{
  curPage: 1
  labelFilterParams: {includeStudyFilterParams: [], excludeStudyFilterParams: [], includeSeriesFilterParams: [],relationType: 1, seriesLevelWithoutTags: false,studyLevelWithoutTags: false}
  excludeSeriesFilterParams: []
  excludeStudyFilterParams: []
  includeSeriesFilterParams: []
  includeStudyFilterParams: []
  relationType: 1
  seriesLevelWithoutTags: false
  studyLevelWithoutTags: false
  pageSize: 10
  searchStr: ""
  sorterField: "updateTime"
  sorterOrder: "DESC"
}

其中curpage是当前页，pageSize是每页的数量，searchStr是患者姓名、病例号、备注的模糊查询，其余字段默认就行了。如果需要查询全部账号下的数据，你可以递增curPage，根据返回值数组的长度 和pageSize比较，判断没有更多数据了

返回值如下

{
code: 1,
data: {pagination: {
  pageCount:1,totalCount:2} ,
  studyList: [
    {
      PatientAge: "074Y",
      PatientID: "0009637617",
      PatientName: "0009637617",
      PatientSex: "M",
      StudyDate: "2021-04-27T16:00:00.000Z",
      StudyInstanceUID: "1.2.840.113564.345049290535.9692.637552042156233117.433089",
      createTime: "2024-04-18T08:02:48.000Z",
      expandAllRows: 0,
      hasOtherStudy: 0,
      id: 12777,
      isDel: "0",
      jsonData: "{}",
      labelList: [],
      pacsUid: "79e7d55c-d417575f-bc461791-44bc886e-08707488",
      physicianOpinion: "",
      status: 0,
      updateTime: "2025-12-03T07:24:22.000Z",
      userId: 2
    }
  ]},
msg: "ok",
}

获取到 studyList数组，根据studyList每一项的StudyInstanceUID，循环再调用 api/v2/getSeriesByStudyInstanceUID 接口获取序列的信息，post类型，入参是

{StudyInstanceUID: string}

返回值如下

{
    "code": 1,
    "msg": "OK",
    "data": [
        {
            "id": 19718,
            "userId": 2,
            "PatientID": "0009637617",
            "physicianOpinion": "",
            "SeriesNumber": "",
            "hasSeeReport": 0,
            "StudyInstanceUID": "1.2.840.113564.345049290535.9692.637552042156233117.433089",
            "SeriesInstanceUID": "1.3.12.2.1107.5.1.4.76315.30000021042706150001900118114",
            "status": 11,
            "createTime": "2024-04-18T08:02:47.000Z",
            "updateTime": "2025-12-03T07:24:22.000Z",
            "uploadTime": "2025-12-03T07:24:22.000Z",
            "analysisStartTime": "2025-12-03T05:30:51.000Z",
            "analysisEndTime": "2025-12-03T05:31:48.000Z",
            "imageCount": 582,
            "SeriesDescription": "Coro  DS_CorCTA  0.75  Bv36  3  BestDiast 74 %",
            "SliceThickness": "0.75",
            "isDel": "0",
            "seriesType": 1,
            "pacsUid": "451ba5fc-b5084543-87123a8e-36f6a95c-4acfe83b",
            "thumbnailPacsUid": "f4666f17-d8aecd64-5e85ecf0-21a45cae-aa8e24b7",
            "labelList": []
        }
    ]
}




